@@ -13,11 +13,12 @@ import pathlib
 import shutil
 import subprocess
 import typing as t
-import warnings
 
 from libtmux import exc, formats
 from libtmux._internal.query_list import QueryList
 from libtmux.common import tmux_cmd
+from libtmux.constants import OptionScope
+from libtmux.hooks import HooksMixin
 from libtmux.neo import fetch_objs
 from libtmux.pane import Pane
 from libtmux.session import Session
@@ -28,9 +29,9 @@ from .common import (
     PaneDict,
     SessionDict,
     WindowDict,
-    has_gte_version,
     session_check_name,
 )
+from .options import OptionsMixin
 
 if t.TYPE_CHECKING:
     import types
@@ -45,7 +46,11 @@ if t.TYPE_CHECKING:
 logger = logging.getLogger(__name__)
 
 
-class Server(EnvironmentMixin):
+class Server(
+    EnvironmentMixin,
+    OptionsMixin,
+    HooksMixin,
+):
     """:term:`tmux(1)` :term:`Server` [server_manual]_.
 
     - :attr:`Server.sessions` [:class:`Session`, ...]
@@ -118,6 +123,11 @@ class Server(EnvironmentMixin):
     formatter_prefix = "server_"
     """Namespace used for :class:`~libtmux.common.TmuxMappingObject`"""
 
+    default_option_scope: OptionScope | None = OptionScope.Server
+    """For option management."""
+    default_hook_scope: OptionScope | None = OptionScope.Server
+    """For hook management."""
+
     def __init__(
         self,
         socket_name: str | None = None,
@@ -302,7 +312,7 @@ class Server(EnvironmentMixin):
 
     @property
     def attached_sessions(self) -> list[Session]:
-        """Return active :class:`Session`s.
+        """Return active :class:`Session` instances.
 
         Examples
         --------
@@ -311,7 +321,8 @@ class Server(EnvironmentMixin):
 
         Returns
         -------
-        list of :class:`Session`
+        list[:class:`Session`]
+            Sessions that are attached.
         """
         return self.sessions.filter(session_attached__noeq="1")
 
@@ -325,7 +336,6 @@ class Server(EnvironmentMixin):
         exact : bool
             match the session name exactly. tmux uses fnmatch by default.
             Internally prepends ``=`` to the session in ``$ tmux has-session``.
-            tmux 2.1 and up only.
 
         Raises
         ------
@@ -337,7 +347,7 @@ class Server(EnvironmentMixin):
         """
         session_check_name(target_session)
 
-        if exact and has_gte_version("2.1"):
+        if exact:
             target_session = f"={target_session}"
 
         proc = self.cmd("has-session", target=target_session)
@@ -477,10 +487,10 @@ class Server(EnvironmentMixin):
             when the command exits. NOTE: When this command exits the window
             will close.  This feature is useful for long-running processes
             where the closing of the window upon completion is desired.
-        x : [int, str], optional
+        x : int | str, optional
             Force the specified width instead of the tmux default for a
             detached session
-        y : [int, str], optional
+        y : int | str, optional
             Force the specified height instead of the tmux default for a
             detached session
 
@@ -515,14 +525,14 @@ class Server(EnvironmentMixin):
             if self.has_session(session_name):
                 if kill_session:
                     self.cmd("kill-session", target=session_name)
-                    logger.info(f"session {session_name} exists. killed it.")
+                    logger.info("session %s exists. killed it.", session_name)
                 else:
                     msg = f"Session named {session_name} exists"
                     raise exc.TmuxSessionExists(
                         msg,
                     )
 
-        logger.debug(f"creating session {session_name}")
+        logger.debug("creating session %s", session_name)
 
         env = os.environ.get("TMUX")
 
@@ -541,7 +551,6 @@ class Server(EnvironmentMixin):
             tmux_args += ("-d",)
 
         if start_directory:
-            # as of 2014-02-08 tmux 1.9-dev doesn't expand ~ in new-session -c.
             start_directory = pathlib.Path(start_directory).expanduser()
             tmux_args += ("-c", str(start_directory))
 
@@ -555,13 +564,8 @@ class Server(EnvironmentMixin):
             tmux_args += ("-y", y)
 
         if environment:
-            if has_gte_version("3.2"):
-                for k, v in environment.items():
-                    tmux_args += (f"-e{k}={v}",)
-            else:
-                logger.warning(
-                    "Environment flag ignored, tmux 3.2 or newer required.",
-                )
+            for k, v in environment.items():
+                tmux_args += (f"-e{k}={v}",)
 
         if window_command:
             tmux_args += (window_command,)
@@ -689,12 +693,11 @@ class Server(EnvironmentMixin):
            Deprecated in favor of :meth:`.kill()`.
 
         """
-        warnings.warn(
-            "Server.kill_server() is deprecated in favor of Server.kill()",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.kill_server()",
+            replacement="Server.kill()",
+            version="0.30.0",
         )
-        self.cmd("kill-server")
 
     def _list_panes(self) -> list[PaneDict]:
         """Return list of panes in :py:obj:`dict` form.
@@ -704,22 +707,21 @@ class Server(EnvironmentMixin):
         The :py:obj:`list` is derived from ``stdout`` in
         :class:`util.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Deprecated in favor of :attr:`.panes`.
 
         """
-        warnings.warn(
-            "Server._list_panes() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._list_panes()",
+            replacement="Server.panes property",
+            version="0.17.0",
         )
-        return [p.__dict__ for p in self.panes]
 
     def _update_panes(self) -> Server:
         """Update internal pane data and return ``self`` for chainability.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Deprecated in favor of :attr:`.panes` and returning ``self``.
 
@@ -727,13 +729,11 @@ class Server(EnvironmentMixin):
         -------
         :class:`Server`
         """
-        warnings.warn(
-            "Server._update_panes() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._update_panes()",
+            replacement="Server.panes property",
+            version="0.17.0",
         )
-        self._list_panes()
-        return self
 
     def get_by_id(self, session_id: str) -> Session | None:
         """Return session by id. Deprecated in favor of :meth:`.sessions.get()`.
@@ -743,45 +743,39 @@ class Server(EnvironmentMixin):
            Deprecated by :meth:`.sessions.get()`.
 
         """
-        warnings.warn(
-            "Server.get_by_id() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.get_by_id()",
+            replacement="Server.sessions.get(session_id=..., default=None)",
+            version="0.16.0",
         )
-        return self.sessions.get(session_id=session_id, default=None)
 
     def where(self, kwargs: dict[str, t.Any]) -> list[Session]:
         """Filter through sessions, return list of :class:`Session`.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Deprecated by :meth:`.session.filter()`.
 
         """
-        warnings.warn(
-            "Server.find_where() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.where()",
+            replacement="Server.sessions.filter()",
+            version="0.17.0",
         )
-        try:
-            return self.sessions.filter(**kwargs)
-        except IndexError:
-            return []
 
     def find_where(self, kwargs: dict[str, t.Any]) -> Session | None:
         """Filter through sessions, return first :class:`Session`.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :meth:`.sessions.get()`.
 
         """
-        warnings.warn(
-            "Server.find_where() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.find_where()",
+            replacement="Server.sessions.get(default=None, **kwargs)",
+            version="0.17.0",
         )
-        return self.sessions.get(default=None, **kwargs)
 
     def _list_windows(self) -> list[WindowDict]:
         """Return list of windows in :py:obj:`dict` form.
@@ -791,68 +785,63 @@ class Server(EnvironmentMixin):
         The :py:obj:`list` is derived from ``stdout`` in
         :class:`common.tmux_cmd` which wraps :py:class:`subprocess.Popen`.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :attr:`.windows`.
 
         """
-        warnings.warn(
-            "Server._list_windows() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._list_windows()",
+            replacement="Server.windows property",
+            version="0.17.0",
         )
-        return [w.__dict__ for w in self.windows]
 
     def _update_windows(self) -> Server:
         """Update internal window data and return ``self`` for chainability.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Deprecated in favor of :attr:`.windows` and returning ``self``.
 
         """
-        warnings.warn(
-            "Server._update_windows() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._update_windows()",
+            replacement="Server.windows property",
+            version="0.17.0",
         )
-        self._list_windows()
-        return self
 
     @property
     def _sessions(self) -> list[SessionDict]:
         """Property / alias to return :meth:`~._list_sessions`.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :attr:`.sessions`.
 
         """
-        warnings.warn(
-            "Server._sessions is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._sessions",
+            replacement="Server.sessions property",
+            version="0.17.0",
         )
-        return self._list_sessions()
 
     def _list_sessions(self) -> list[SessionDict]:
         """Return list of session object dictionaries.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :attr:`.sessions`.
         """
-        warnings.warn(
-            "Server._list_sessions() is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server._list_sessions()",
+            replacement="Server.sessions property",
+            version="0.17.0",
         )
-        return [s.__dict__ for s in self.sessions]
 
     def list_sessions(self) -> list[Session]:
         """Return list of :class:`Session` from the ``tmux(1)`` session.
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :attr:`.sessions`.
 
@@ -860,25 +849,23 @@ class Server(EnvironmentMixin):
         -------
         list of :class:`Session`
         """
-        warnings.warn(
-            "Server.list_sessions is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.list_sessions()",
+            replacement="Server.sessions property",
+            version="0.17.0",
         )
-        return self.sessions
 
     @property
     def children(self) -> QueryList[Session]:
         """Was used by TmuxRelationalObject (but that's longer used in this class).
 
-        .. deprecated:: 0.16
+        .. deprecated:: 0.17
 
            Slated to be removed in favor of :attr:`.sessions`.
 
         """
-        warnings.warn(
-            "Server.children is deprecated",
-            category=DeprecationWarning,
-            stacklevel=2,
+        raise exc.DeprecatedError(
+            deprecated="Server.children",
+            replacement="Server.sessions property",
+            version="0.17.0",
         )
-        return self.sessions
